(document:surround "/std/frame")

;;; UI

(box
  orientation "vertical"
  margin 10
  (document:id sl (slideshow))
  (label name "stage")
  (document:id progress (progressbar maximum 100 value 0 visibility #f))
  (label name "status" text-wrap #t))


;;; logic

(define (ui-stop)
  (remove-mailbox ui-callback))

(define (ui-done)
  (ui-stop)
  (frame:next))

(define (ui-error reason)
  (ui-stop)
  (form-update-value "stage"
                     (bold (_ "Fatal error")))
  (form-update-value "status"
                     reason))


(define (ui-stage stage)
  (form-update-value "status" "")
  (case stage
    ((install)   (progress visibility #t)))
  (form-update-value "stage"
                     (bold
                       (case stage
                         ((preinstall) (_ "Preparing..."))
                         ((install)(_ "Installing system from base image..."))
                         ((mount_chroot) (_ "Mounting virtual filesystems..."))
                         ((systemd_tmpfiles_chroot) (_ "Running systemd-tmpfiles..."))
                         ((done) (_ "Installation from base image is done"))))))

(define (ui-callback args)
  (case (car args)
    ((stage)
     (let ((stage (string->symbol (cadr args))))
       (ui-stage stage)
       (and (eq? stage 'done) (ui-done))))
    ((error)
       (ui-error (cadr args)))
    ((status)
     (let ((percent (cadr args)))
     (progress text (string-append percent "%"))
     (progress value percent)))))

(define (slideshow-config)
  (catch/message
	(lambda()
	  (let ((config (woo-read-first "/installer-livecd-install/slideshow-config")))
		(sl step (woo-get-option config 'step))
		(sl once (woo-get-option config 'once))
		(sl url (woo-get-option config 'url))))))

;;;;;;
;;; Notify backend to start unpack squashfs
;;;
(define (ready)
  (catch/message
    (lambda()
     (woo-write "/installer-livecd-install"))))

(document:root
  (when loaded
    (frame:next-activity #f)
    (frame:back-activity #f)
    (add-mailbox ui-callback)
    (slideshow-config)
    (sl start #t)
    (ready)))
